@@ -426,22 +426,34 @@ class MultiCompleter():
             return None
 
 class InstanceTypesCompleter():
-    InstanceTypeSpec = namedtuple('InstanceTypeSpec', ('Name', 'Memory_GB_Per_Core', 'Storage_GB_Per_Core', 'CPU_Cores'))
+    InstanceTypeSpec = namedtuple('InstanceTypeSpec', ('Name', 'Memory_GB', 'Storage_GB', 'CPU_Cores'))
     instance_types = OrderedDict()
-    for i in (InstanceTypeSpec('mem2_hdd2_x1', 3.75, 380, 1),
-              InstanceTypeSpec('mem2_hdd2_x2', 3.75, 400, 2),
-              InstanceTypeSpec('mem2_hdd2_x4', 3.75, 400, 4),
-              InstanceTypeSpec('mem1_hdd2_x8', .87, 200, 8),
-              InstanceTypeSpec('mem3_hdd2_x2', 8.55, 200, 2),
-              InstanceTypeSpec('mem3_hdd2_x4', 8.55, 200, 4),
-              InstanceTypeSpec('mem3_hdd2_x8', 8.55, 200, 8),
-              InstanceTypeSpec('mem1_hdd2_x32', 1.89, 100, 32),
-              InstanceTypeSpec('mem1_hdd2_gpu1_x16', 1.41, 100, 16),
-              InstanceTypeSpec('mem3_ssd1_x32', 7.62, 7, 32),
-              InstanceTypeSpec('mem3_ssd2_x4', 7.62, 175, 4),
-              InstanceTypeSpec('mem3_ssd2_x8', 7.62, 175, 8),
-              InstanceTypeSpec('mem3_ssd2_x16', 7.62, 175, 16),
-              InstanceTypeSpec('mem3_ssd2_x32', 7.62, 175, 32)):
+    for i in (InstanceTypeSpec('mem1_ssd1_x2', 3.8, 32, 2),
+              InstanceTypeSpec('mem1_ssd1_x4', 7.5, 80, 4),
+              InstanceTypeSpec('mem1_ssd1_x8', 15.0, 160, 8),
+              InstanceTypeSpec('mem1_ssd1_x16', 30.0, 320, 16),
+              InstanceTypeSpec('mem1_ssd1_x32', 60.0, 640, 32),
+
+              InstanceTypeSpec('mem1_hdd2_x8', 7.0, 1680, 8),
+              InstanceTypeSpec('mem1_hdd2_x32', 60.5, 3360, 32),
+
+              InstanceTypeSpec('mem2_ssd1_x2', 7.5, 32, 2),
+              InstanceTypeSpec('mem2_ssd1_x4', 15.0, 80, 4),
+              InstanceTypeSpec('mem2_ssd1_x8', 30.0, 160, 8),
+
+              InstanceTypeSpec('mem2_hdd2_x1', 3.8, 410, 1),
+              InstanceTypeSpec('mem2_hdd2_x2', 7.5, 840, 2),
+              InstanceTypeSpec('mem2_hdd2_x4', 15.0, 1680, 4),
+
+              InstanceTypeSpec('mem3_ssd1_x2', 15.0, 32, 2),
+              InstanceTypeSpec('mem3_ssd1_x4', 30.5, 80, 4),
+              InstanceTypeSpec('mem3_ssd1_x8', 61.0, 160, 8),
+              InstanceTypeSpec('mem3_ssd1_x16', 122.0, 320, 16),
+              InstanceTypeSpec('mem3_ssd1_x32', 244.0, 640, 32),
+
+              InstanceTypeSpec('mem3_hdd2_x2', 17.1, 420, 2),
+              InstanceTypeSpec('mem3_hdd2_x4', 34.2, 850, 4),
+              InstanceTypeSpec('mem3_hdd2_x8', 68.4, 1680, 8)):
         instance_types[i.Name] = i
     instance_type_names = instance_types.keys()
 
